plot_fermi_cross_section — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# plot_fermi_cross_section

FermiHandler.plot_fermi_cross_section(mode, slice_normal: Tuple[float, float, float] = (1, 0, 0), slice_origin: Tuple[float, float, float] = (0, 0, 0), bands=None, atoms=None, orbitals=None, spins=None, spin_texture=False, show=True, save_2d=None, save_2d_slice=None, print_plot_opts: bool = False, **kwargs)

  A method to plot the 3d fermi surface

  Parameters:

    - mode (str) – The mode to calculate

    - bands (List[int], optional) – A list of band indexes to plot, by default None

    - atoms (List[int], optional) – A list of atoms, by default None

    - orbitals (List[int], optional) – A list of orbitals, by default None

    - spins (List[int], optional) – A list of spins, by default None

    - spin_texture (bool, optional) – Boolean to plot spin texture, by default False

    - print_plot_opts (bool, optional) – Boolean to print the plotting options